@@ -1,5 +1,5 @@
-# Author: Vlad Niculae
-# License: BSD 3 clause
+# Authors: The scikit-learn developers
+# SPDX-License-Identifier: BSD-3-Clause
 
 import sys
 
@@ -14,6 +14,7 @@ from sklearn.utils._testing import (
     assert_array_almost_equal,
     if_safe_multiprocessing_with_blas,
 )
+from sklearn.utils.extmath import svd_flip
 
 
 def generate_toy_data(n_components, n_samples, image_size, random_state=None):
@@ -114,18 +115,21 @@ def test_initialization():
         n_components=3, U_init=U_init, V_init=V_init, max_iter=0, random_state=rng
     )
     model.fit(rng.randn(5, 4))
-    assert_allclose(model.components_, V_init / np.linalg.norm(V_init, axis=1)[:, None])
+
+    expected_components = V_init / np.linalg.norm(V_init, axis=1, keepdims=True)
+    expected_components = svd_flip(u=expected_components.T, v=None)[0].T
+    assert_allclose(model.components_, expected_components)
 
 
 def test_mini_batch_correct_shapes():
     rng = np.random.RandomState(0)
     X = rng.randn(12, 10)
-    pca = MiniBatchSparsePCA(n_components=8, random_state=rng)
+    pca = MiniBatchSparsePCA(n_components=8, max_iter=1, random_state=rng)
     U = pca.fit_transform(X)
     assert pca.components_.shape == (8, 10)
     assert U.shape == (12, 8)
     # test overcomplete decomposition
-    pca = MiniBatchSparsePCA(n_components=13, random_state=rng)
+    pca = MiniBatchSparsePCA(n_components=13, max_iter=1, random_state=rng)
     U = pca.fit_transform(X)
     assert pca.components_.shape == (13, 10)
     assert U.shape == (12, 13)
@@ -268,35 +272,6 @@ def test_spca_feature_names_out(SPCA):
     assert_array_equal([f"{estimator_name}{i}" for i in range(4)], names)
 
 
-# TODO (1.4): remove this test
-def test_spca_n_iter_deprecation():
-    """Check that we raise a warning for the deprecation of `n_iter` and it is ignored
-    when `max_iter` is specified.
-    """
-    rng = np.random.RandomState(0)
-    n_samples, n_features = 12, 10
-    X = rng.randn(n_samples, n_features)
-
-    warn_msg = "'n_iter' is deprecated in version 1.1 and will be removed"
-    with pytest.warns(FutureWarning, match=warn_msg):
-        MiniBatchSparsePCA(n_iter=2).fit(X)
-
-    n_iter, max_iter = 1, 100
-    with pytest.warns(FutureWarning, match=warn_msg):
-        model = MiniBatchSparsePCA(
-            n_iter=n_iter, max_iter=max_iter, random_state=0
-        ).fit(X)
-    assert model.n_iter_ > 1
-    assert model.n_iter_ <= max_iter
-
-
-def test_pca_n_features_deprecation():
-    X = np.array([[-1, -1], [-2, -1], [-3, -2], [1, 1], [2, 1], [3, 2]])
-    pca = PCA(n_components=2).fit(X)
-    with pytest.warns(FutureWarning, match="`n_features_` was deprecated"):
-        pca.n_features_
-
-
 def test_spca_early_stopping(global_random_seed):
     """Check that `tol` and `max_no_improvement` act as early stopping."""
     rng = np.random.RandomState(global_random_seed)
